function summaryTable = summarize(self, propList)
    % SUMMARIZE Summarize results into a single clean table.
    %   This method outputs a table with the operating conditions and the final values found for
    %   various properties.
    % -----
    %
    % Syntax:
    %   Result.summarize() Outputs a table with all available data (cT, cQ, cP).
    %
    %   Result.summarize(propList) Outputs a table with only the data listed in propList.
    %
    % Inputs:
    %   propList : (optional) Array with the names of the properties to ouptut. {'cT', 'cQ', 'cP'}
    %
    % Outputs:
    %   summaryTable : Table with the operating points and the corresponding rotor performance.
    %
    % See also: rotare, Result, template.
    %
    % <a href="https://gitlab.uliege.be/rotare/documentation">Complete documentation (online)</a>

    % ----------------------------------------------------------------------------------------------
    % (c) Copyright 2022-2023 University of Liege
    % Author: Thomas Lambert <t.lambert@uliege.be>
    % ULiege - Aeroelasticity and Experimental Aerodynamics
    % MIT License
    % Repo: https://gitlab.uliege.be/rotare/rotare
    % Docs: https://gitlab.uliege.be/rotare/documentation
    % Issues: https://gitlab.uliege.be/rotare/rotare/-/issues
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    % Defaults and constants
    ALLOWED_PROPERTIES = {'cT', 'cQ', 'cP'};

    if nargin < 2
        propList = ALLOWED_PROPERTIES;
    end

    propTable = table;
    for i = 1:length(propList)
        propTable = [propTable, self.(propList{i})];
    end
    summaryTable = [self.operPts, propTable];

    self.operPts;
end
